@@ -17,21 +17,19 @@
 # limitations under the License.
 """Marshmallow schema implementation that supports JSON-LD."""
 
-from marshmallow.schema import Schema, SchemaMeta, SchemaOpts
-from marshmallow.utils import missing, is_collection, RAISE, set_value, EXCLUDE, INCLUDE
-from marshmallow import post_load
-from collections.abc import Mapping
-from marshmallow.error_store import ErrorStore
-from rdflib.plugins.sparql import prepareQuery
-from uuid import uuid4
-import rdflib
-from pyld import jsonld
-
 import inspect
 import typing
+from collections.abc import Mapping
 from functools import lru_cache
+from uuid import uuid4
 
-from calamus.utils import normalize_id, normalize_type, Proxy, validate_field_properties
+from marshmallow import post_load
+from marshmallow.error_store import ErrorStore
+from marshmallow.schema import Schema, SchemaMeta, SchemaOpts
+from marshmallow.utils import EXCLUDE, INCLUDE, RAISE, is_collection, missing, set_value
+from pyld import jsonld
+
+from calamus.utils import Proxy, normalize_id, normalize_type, validate_field_properties
 
 _T = typing.TypeVar("_T")
 
@@ -388,11 +386,13 @@ class JsonLDSchema(Schema, metaclass=JsonLDSchemaMeta):
             return_valid_data (bool): Whether to delete invalid properties to return only valid data or else
                 returns a dict containing valid and invalid properties, Default: ``False``
         """
+        from rdflib.graph import Graph
+        from rdflib.plugins.sparql import prepareQuery
 
         if isinstance(data, self.Meta.model) or all(isinstance(s, self.Meta.model) for s in data):
             data = self.dump(data)
 
-        g = rdflib.Graph()
+        g = Graph()
         if not isinstance(ontology, list):
             ontology = [ontology]
 
@@ -550,6 +550,17 @@ class JsonLDAnnotation(type):
     def __new__(mcs, name, bases, namespace, **kwargs):
         import calamus.fields as fields
 
+        base_schemas = (JsonLDSchema,)
+
+        if bases:
+            potential_base_schemas = [
+                base.__calamus_schema__
+                for base in bases
+                if hasattr(base, "__calamus_schema__") and issubclass(base.__calamus_schema__, JsonLDSchema)
+            ]
+            if potential_base_schemas:
+                base_schemas = tuple(potential_base_schemas)
+
         attribute_dict = {}
         for attr_name, value in namespace.copy().items():
             if isinstance(value, fields._JsonLDField):
@@ -567,7 +578,7 @@ class JsonLDAnnotation(type):
             raise ValueError("Setting 'rdf_type' on the `class Meta` is required for calamus annotations")
 
         attribute_dict["Meta"] = type("Meta", (), {"rdf_type": namespace["Meta"].rdf_type})
-        namespace["__calamus_schema__"] = type(f"{name}Schema", (JsonLDSchema,), attribute_dict)
+        namespace["__calamus_schema__"] = type(f"{name}Schema", base_schemas, attribute_dict)
 
         @lru_cache(maxsize=5)
         def schema(*args, **kwargs):
